% 'main2.m' reads file 'enrgwave.txt', where 'enrgwave.txt' is output of
% function 'main1.m' and calculates scattering rates, the total
% relaxation rates, population inversion and the optical gain in the
% presence of an intense external magnetic field

% Open a wait bar dialog box
h_wait = waitbar(0,'Please wait...',...
    'Position',[250,320,290,50],...
    'CloseRequestFcn',@close_waitbar);
% Update a wait bar dialog box
waitbar(1/((Bmax-Bmin)/dB+1),h_wait)

param1
param2

% Load energy eigenvalues ​​and wave functions from the file 'enrgwave.txt'
% -------------------------------------------------------------------------
fid = fopen('enrgwave.txt','r');
Nn = fscanf(fid, '%d', 1);
Nz = fscanf(fid, '%d', 1);
En = zeros(1, Nn);
for i = 1 : Nn
    En(i) = fscanf(fid, '%f', 1);
end
eta = zeros(Nn, Nz);
for j = 1 : Nz
    for i = 1 : Nn
        eta(i, j) = fscanf(fid, '%f', 1);
    end
end
fclose(fid);
% -------------------------------------------------------------------------

% Parallel mass
% -------------------------------------------------------------------------
mp1 = mw * (1 + (2 * alpha1p + beta1p) * (En(1) - Unef));
mp1 = 1 / (sum(eta(1, :) .^ 2 .* (1 ./ mp1)) * dz);
mp2 = mw * (1 + (2 * alpha1p + beta1p) * (En(2) - Unef));
mp2 = 1 / (sum(eta(2, :) .^ 2 .* (1 ./ mp2)) * dz);
mp3 = mw * (1 + (2 * alpha1p + beta1p) * (En(3) - Unef));
mp3 = 1 / (sum(eta(3, :) .^ 2 .* (1 ./ mp3)) * dz);
% -------------------------------------------------------------------------

% Dipole matrix element
d32 = dipol(eta(3, :), eta(2, :), En(3), En(2), mp3, mp2);

% LO scattering
% -------------------------------------------------------------------------
%maksimum beta
beta_max = sqrt(e * Bmax / hbar) * Angstrom; % 1 / Angstrom

% qp boundary and integration step
qpcut = NQPcut * sqrt(2) * beta_max; % 1 / Angstrom
dqp = qpcut / NQPstep; % 1 / Angstrom
qp = 0 : dqp: qpcut; % 1 / Angstrom

% function G(qp)
Gqp = zeros(Nn, length(qp), Nn);
for n2 = 1 : Nn
    for n1 = n2 : Nn        
        Gqp(n2, :, n1) = GQP(eta(n2, :), eta(n1, :), qp, z);
        if (n2 ~= n1)
            Gqp(n1, :, n2) = Gqp(n2, :, n1);
        end
    end
end
% -------------------------------------------------------------------------

if or(DELTA==0, LAMBDA==0)
    LOonly; % if an IR parameter is zero, only LO-phonon scattering influence on the operation of QCL
else
    LOandIR; % consider LO-phonon and IR scattering
end

B = Bmin : dB : Bmax;

% Results are written to a file 'res.txt'
% -------------------------------------------------------------------------
fid = fopen('res.txt', 'w');
fprintf(fid, '%d\n\n', length(B));
fprintf(fid, '%4.1f ', Bmin);
fprintf(fid, '%4.1f ', dB);
fprintf(fid, '%5.1f ', Bmax);
fprintf(fid, '%3.0f ', TEMP);
fprintf(fid, '\n\n');
for i = 1 : length(B)
    fprintf(fid, '%4.1f ', B(i));
    fprintf(fid, '%18.15f ', W30lo(i));
    fprintf(fid, '%18.15f ', W30ir(i));
    fprintf(fid, '%18.15f ', W30loir(i));
    fprintf(fid, '%16.0f ', N20lo(i));
    fprintf(fid, '%16.0f ', N30lo(i));
    fprintf(fid, '%16.0f ', N20loir(i));
    fprintf(fid, '%16.0f ', N30loir(i));
    fprintf(fid, '%18.15f ', g32lo(i));
    fprintf(fid, '%18.15f ', g32loir(i));
    fprintf(fid, '\n');
end
fclose(fid);
% -------------------------------------------------------------------------
  
% When waitbar reaches max, close it.
if ishandle(h_wait)        
    close(h_wait)
end
