% Plot default results for wavelength=11.2x10^(-6)m in magnetic field range 
% B=3-60T at temperature T=77K.

% Fig1. The subband positions at zero magnetic fields, together with the
% coresponding wave functions squared
% -------------------------------------------------------------------------
z_init = dlmread('z_init.txt',',');
U_init = dlmread('U_init.txt',',');
fid = fopen('enrgwave_init.txt','r');
Nn_init = fscanf(fid, '%d', 1);
Nz_init = fscanf(fid, '%d', 1);
En_init = zeros(1, Nn_init);
for i = 1 : Nn_init
    En_init(i) = fscanf(fid, '%f', 1);
end
eta_init = zeros(Nn_init, Nz_init);
for j = 1 : Nz_init
    for i = 1 : Nn_init
        eta_init(i, j) = fscanf(fid, '%f', 1);
    end
end
fclose(fid);
subplot(2,2,1, 'Parent', panelFigure)
plot(z_init, U_init,'linewidth',font_scale*4)
xlabel(['z [',197,']'],'Fontsize',font_scale*15)
ylabel('U [eV]','Fontsize',font_scale*15)
title('Conduction band diagram. Wave functions','FontWeight','bold','Fontsize',font_scale*15)
hold on
for i = 1 : Nn_init
    plot( z_init(1 : floor(end / 100) : end), En_init(i), 'b--','linewidth',font_scale*4)
    text(z_init(1), En_init(i), ['\color{blue}', '{\itE}_{', int2str(i), '}'], 'HorizontalAlignment','right','Fontsize',font_scale*15)
    plot(z_init, En_init(i) + eta_init(i, :) .* eta_init(i, :), 'r','linewidth',font_scale*4)
end
hold off

% load results from file 'res_init.txt'
% -------------------------------------------------------------------------
fid = fopen('res_init.txt','r');
NB_init = fscanf(fid, '%d', 1);
Bmin_init = fscanf(fid, '%f', 1);
dB_init = fscanf(fid, '%f', 1);
Bmax_init = fscanf(fid, '%f', 1);
TEMP_init = fscanf(fid, '%f', 1);
B_init = zeros(1, NB_init);
W30lo_init = zeros(1, NB_init);
W30ir_init = zeros(1, NB_init);
W30loir_init = zeros(1, NB_init);
N20lo_init = zeros(1, NB_init);
N30lo_init = zeros(1, NB_init);
N20loir_init = zeros(1, NB_init);
N30loir_init = zeros(1, NB_init);
g32lo_init = zeros(1, NB_init);
g32loir_init = zeros(1, NB_init);
for i = 1 : NB_init
    B_init(i) = fscanf(fid, '%f ', 1);
    W30lo_init(i) = fscanf(fid, '%f', 1);
    W30ir_init(i) = fscanf(fid, '%f', 1);
    W30loir_init(i) = fscanf(fid, '%f', 1);
    N20lo_init(i) = fscanf(fid, '%f', 1);
    N30lo_init(i) = fscanf(fid, '%f', 1);
    N20loir_init(i) = fscanf(fid, '%f', 1);
    N30loir_init(i) = fscanf(fid, '%f', 1);
    g32lo_init(i) = fscanf(fid, '%f', 1);
    g32loir_init(i) = fscanf(fid, '%f', 1);
end
fclose(fid);
% -------------------------------------------------------------------------


% Fig2. The total electron relaxation rate for transitions from (3, 0) subband 
% into the (2, l) and (1, l) subbands
% -------------------------------------------------------------------------
subplot(2,2,2), plot(B_init, W30lo_init, '--', B_init, W30ir_init, '-.', B_init, W30loir_init,'linewidth',font_scale*4)
xlabel('B [T]','Fontsize',font_scale*15)
ylabel('1 / \tau_{3,0} [1/ps]','Fontsize',font_scale*15)
title('Relaxation rate','FontWeight','bold','Fontsize',font_scale*15)
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm IR}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off','Fontsize',font_scale*15)

% Fig3. The ratio of the total electron areal densities in the ground laser
% levels of the third and the second subband
% -------------------------------------------------------------------------
subplot(2,2,3), plot(B_init, N30lo_init ./ N20lo_init, 'b--', B_init, N30loir_init ./ N20loir_init, 'r','linewidth',font_scale*4)
title('Population inversion','FontWeight','bold','Fontsize',font_scale*15)
xlabel('B [T]','Fontsize',font_scale*15)
ylabel('N_{3,0} / N_{2,0}','Fontsize',font_scale*15)
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off','Fontsize',font_scale*15)

% Fig4. QCL gain
% -------------------------------------------------------------------------
subplot(2,2,4), plot(B_init, g32lo_init, 'b--', B_init, g32loir_init, 'r','linewidth',font_scale*4)
title('The optical gain','FontWeight','bold','Fontsize',font_scale*15)
xlabel('B [T]','Fontsize',font_scale*15)
ylabel('g [{cm}^2 / {kA}]','Fontsize',font_scale*15)
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off','Fontsize',font_scale*15)

set(findobj('type','axes'),'Fontsize',font_scale*15)